@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_mediatailor.paginator import ListPlaybackConfigurationsPaginator
@@ -45,19 +46,20 @@ class Exceptions:
 
 class MediaTailorClient:
     """
-    [MediaTailor.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client)
+    [MediaTailor.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
         """
 
     def delete_playback_configuration(self, Name: str) -> Dict[str, Any]:
         """
-        [Client.delete_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
+        [Client.delete_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
         """
 
     def generate_presigned_url(
@@ -68,24 +70,24 @@ class MediaTailorClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
         """
 
     def get_playback_configuration(self, Name: str) -> GetPlaybackConfigurationResponseTypeDef:
         """
-        [Client.get_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
+        [Client.get_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
         """
 
     def list_playback_configurations(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListPlaybackConfigurationsResponseTypeDef:
         """
-        [Client.list_playback_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
+        [Client.list_playback_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
         """
 
     def put_playback_configuration(
@@ -104,22 +106,22 @@ class MediaTailorClient:
         VideoContentSourceUrl: str = None,
     ) -> PutPlaybackConfigurationResponseTypeDef:
         """
-        [Client.put_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
+        [Client.put_playback_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
         """
 
     def get_paginator(
         self, operation_name: Literal["list_playback_configurations"]
     ) -> ListPlaybackConfigurationsPaginator:
         """
-        [Paginator.ListPlaybackConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
+        [Paginator.ListPlaybackConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
         """
